@@ -37,6 +37,11 @@ class ConflictError(FastAgaveError):
     status_code: int = 409
 
 
+@dataclass
+class UnprocessableEntity(FastAgaveError):
+    status_code: int = 422
+
+
 @dataclass
 class TooManyRequests(FastAgaveError):
     status_code: int = 429
